# DATI
param nC;               # Numero di cacciatori
set Ca := 1..nC;        # Insieme dei cacciatori
set P;                  # Insieme dei paesi
param nn {P};           # Popolazione stimata di nutrie in ogni paese
param NmaxPaesi;        # Max num. di paesi assegnati ad ogni cacciatore

# VARIABILI
# Variabili di assegnamento paesi-cacciatori
var x {P,Ca} binary;
# Quote di ogni cacciatore in ogni paese
var quota {p in P} = nn[p]/sum {c in Ca} x[p,c];
# Max munero di nutrie assegnate ad un cacciatore
var delta >=0;

# VINCOLO
# Non pi di NmaxPaesi per ogni cacciatore
subject to N_ass_c {c in Ca}:
  sum {p in P} x[p,c] <= NmaxPaesi;

# Almeno un cacciatore per ogni paese
subject to N_ass_p {p in P}:
  sum {c in Ca} x[p,c] >= 1;

# OBIETTIVO
# Minimizzare massimo numero di nutrie assegnate ad un cacciatore
minimize z: delta;

# Vincoli per linearizzare l'obiettivo
subject to MinMax {c in Ca}:
  delta >= sum {p in P} x[p,c] * quota[p];

####################
data;
set P:= A B C D E F G H I L;
param nC := 5;
param NmaxPaesi := 3;

param nn :=
A 20
B 30
C 24
D 36
E 80
F 72
G 54
H 37
I 25
L 47;

end;
